changeset 90123:b34d1b1795af

Encoding changed to utf-8-emacs. Register ethio-composition-function in composition-function-table. ("Ethiopic"): Coding-systems changed to utf-8-emacs.
author Kenichi Handa <handa@m17n.org>
date Wed, 16 Mar 2005 11:44:38 +0000
parents 4448038ca381
children 440c632022e0
files lisp/language/ethiopic.el
diffstat 1 files changed, 24 insertions(+), 19 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/language/ethiopic.el	Wed Mar 16 11:44:14 2005 +0000
+++ b/lisp/language/ethiopic.el	Wed Mar 16 11:44:38 2005 +0000
@@ -1,7 +1,10 @@
 ;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
 
 ;; Copyright (C) 1995, 2001 Electrotechnical Laboratory, JAPAN.
-;; Licensed to the Free Software Foundation.
+;;   Licensed to the Free Software Foundation.
+;; Copyright (C) 2005
+;;   National Institute of Advanced Industrial Science and Technology (AIST)
+;;   Registration Number: H15PRO 110
 
 ;; Keywords: multilingual, Ethiopic
 
@@ -54,30 +57,32 @@
  "Ethiopic" '((setup-function . setup-ethiopic-environment-internal)
 	      (exit-function . exit-ethiopic-environment)
 	      (charset ethiopic)
-	      (coding-system iso-2022-7bit)
-	      (coding-priority iso-2022-7bit)
+	      (coding-system utf-8-emacs)
+	      (coding-priority utf-8-emacs)
 	      (input-method . "ethiopic")
 	      (features ethio-util)
-	      (sample-text . "$(3$Q#U!.(B")
+	      (sample-text . "ፊደል")
 	      (documentation .
-"This language envrironment provides these function key bindings
-    \(old bindings are shown in parentheses):
-    [f3]   ethio-fidel-to-sera-buffer         (f5)
-    [S-f3] ethio-fidel-to-sera-region         (f5)
-    [C-f3] ethio-fidel-to-sera-mail-or-marker (f5)
+"This language envrironment provides these function key bindings:
+    [f3]   ethio-fidel-to-sera-buffer
+    [S-f3] ethio-fidel-to-sera-region
+    [C-f3] ethio-fidel-to-sera-marker
+
+    [f4]   ethio-sera-to-fidel-buffer
+    [S-f4] ethio-sera-to-fidel-region
+    [C-f4] ethio-sera-to-fidel-marker
 
-    [f4]   ethio-sera-to-fidel-buffer         (unchanged)
-    [S-f4] ethio-sera-to-fidel-region         (unchanged)
-    [C-f4] ethio-sera-to-fidel-mail-or-marker (unchanged)
+    [S-f5] ethio-toggle-punctuation
+    [S-f6] ethio-modify-vowel
+    [S-f7] ethio-replace-space
 
-    [S-f5] ethio-toggle-punctuation           (f3)
-    [S-f6] ethio-modify-vowel                 (f6)
-    [S-f7] ethio-replace-space                (f7)
-    [S-f8] ethio-input-special-character      (f8)
-    [S-f9] ethio-replace-space                (unchanged)
-    [C-f9] ethio-toggle-space                 (f2)"
+    [S-f9] ethio-replace-space
+    [C-f9] ethio-toggle-space"
 )))
 
+;; For automatic composition
+(aset composition-function-table ? 'ethio-composition-function)
+
 (provide 'ethiopic)
 
 ;;; arch-tag: e81329d9-1286-43ba-92fd-54ce5c7b213c
@@ -1,7 +1,10 @@
-;;; ethiopic.el --- support for Ethiopic -*- coding: iso-2022-7bit; -*-
+;;; ethiopic.el --- support for Ethiopic	-*- coding: utf-8-emacs; -*-
 
 ;; Copyright (C) 1995, 2001 Electrotechnical Laboratory, JAPAN.